@@ -133,6 +133,8 @@ class TestShifting(unittest.TestCase):
         srt_file = SubRipFile([SubRipItem()])
         srt_file.shift(1, 1, 1, 1)
         self.assertEquals(srt_file[0].end, (1, 1, 1, 1))
+        srt_file.shift(ratio=2)
+        self.assertEquals(srt_file[0].end, (2, 2, 2, 2))
 
 
 class TestDuckTyping(unittest.TestCase):
@@ -213,3 +215,18 @@ class TestBOM(unittest.TestCase):
 
     def test_utf32be(self):
         self.__test_encoding('bom-utf-32-be.srt')
+
+
+class TestIntegration(unittest.TestCase):
+    """
+    Test some borderlines features found on
+    http://ale5000.altervista.org/subtitles.htm
+    """
+
+    def setUp(self):
+        self.base_path = os.path.join(file_path, 'tests', 'static')
+
+    def test_length(self):
+        path = os.path.join(self.base_path, 'capability_tester.srt')
+        file = SubRipFile.open(path)
+        self.assertEquals(len(file), 37)
