@@ -51,6 +51,11 @@ class TestShifting(unittest.TestCase):
         self.assertEqual(self.item.start, (3, 58, 56, 996))
         self.assertEqual(self.item.end, (3, 59, 16, 996))
 
+    def test_shift_by_ratio(self):
+        self.item.shift(ratio=2)
+        self.assertEqual(self.item.start, {'minutes': 2})
+        self.assertEqual(self.item.end, {'minutes': 2, 'seconds': 40})
+
 
 class TestOperators(unittest.TestCase):
 
@@ -71,6 +76,9 @@ class TestSerialAndParsing(unittest.TestCase):
         self.item.end.shift(seconds=20)
         self.string = u'1\n00:01:00,000 --> 00:01:20,000\nHello world !\n'
         self.bad_string = u'foobar'
+        self.coordinates = (u'1\n00:01:00,000 --> 00:01:20,000 X1:000 X2:000 '
+                                'Y1:050 Y2:100\nHello world !\n')
+        self.dots = u'1\n00:01:00.000 --> 00:01:20.000\nHello world !\n'
 
     def test_serialization(self):
         self.assertEqual(unicode(self.item), self.string)
@@ -79,3 +87,9 @@ class TestSerialAndParsing(unittest.TestCase):
         self.assertEquals(SubRipItem.from_string(self.string), self.item)
         self.assertRaises(InvalidItem, SubRipItem.from_string,
             self.bad_string)
+
+    def test_coordinates(self):
+        self.assertEquals(SubRipItem.from_string(self.coordinates), self.item)
+
+    def test_dots(self):
+        self.assertEquals(SubRipItem.from_string(self.dots), self.item)
