@@ -75,6 +75,9 @@ class TestTimeParsing(unittest.TestCase):
         for time_string, time_items in self.KNOWN_VALUES:
             self.assertEquals(time_string, str(SubRipTime(*time_items)))
 
+    def test_negative_serialization(self):
+        self.assertEquals('00:00:00,000', SubRipTime(-1, 2, 3, 4))
+
     def test_invalid_time_string(self):
         self.assertRaises(InvalidTimeString, SubRipTime.from_string, 'hello')
 
